@@ -2,11 +2,7 @@ from __future__ import print_function
 
 import logging
 
-log = logging.getLogger('SQCommon')
-log.addHandler(logging.StreamHandler())
-if log.level == logging.NOTSET:
-    log.setLevel(logging.INFO)
-
+log = logging.getLogger('SKQ.Common')
 
 __all__ = ['Result', 'Stats']
 
